@@ -18,7 +18,7 @@ use Path::Tiny;
 use IO::Handle;
 use POSIX qw/:errno_h/;
 
-our $VERSION     = '0.17';
+our $VERSION     = '0.18';
 our @EXPORT_OK   = qw/hosts_from_map is_host multi_run shell_quote tmux/;
 our %EXPORT_TAGS = ();
 
@@ -183,9 +183,10 @@ sub tmux {
 
     my $layout = layout(@commands);
     my $tmux   = '';
+    my $pct    = int( 100 / scalar @commands );
 
     for my $ssh (@commands) {
-        my $cmd = !$tmux ? 'new-session' : '\\; split-window -d';
+        my $cmd = !$tmux ? 'new-session' : '\\; split-window -d -p ' . $pct;
 
         $tmux .= " $cmd " . shell_quote($ssh);
     }
@@ -266,7 +267,7 @@ App::MultiSsh - Multi host ssh executer
 
 =head1 VERSION
 
-This documentation refers to App::MultiSsh version 0.17
+This documentation refers to App::MultiSsh version 0.18
 
 =head1 SYNOPSIS
 
